@@ -158,7 +158,7 @@ def collect_inputs():
                         print('\n\u274C There was an error with the provided context. Please review your input, verify that the context exists, and try again.\n\n', e)
                         exit()
             
-            print(clear, '\nContext:',usecontext)
+            print(clear, '\rContext:',usecontext)
 
             # Get context info
             try:
@@ -175,7 +175,7 @@ def collect_inputs():
                     raise Exception("Cluster not found within context. Please add a cluster to your context config and try again.")
                 if "namespace" in contextdata: 
                     print("\n**NOTE: A namespace has been found in the context you're using. Please note that you will still be required to provide a \
-    namespace that will be used in the program execution if you have not already included one with CLI input.")
+namespace that will be used in the program execution if you have not already included one with CLI input.")
 
             except Exception as e:
                 print('\n\u274C There was an error finding the cluster with the context provided. Please review your input, verify that the context exists, and try again.\n\n', e)
