@@ -30,11 +30,13 @@ def upload_to_s3(bucket_name, file, account, image_digest, image_name):
         image_name = image_name.split('@')[0] + "NOTAG"
     
     image_name = image_name.removeprefix('http://').removeprefix('https://')
-    
     tag = image_name.split(':')[-1]
     registry = image_name.split('/', 1)[0]
     repository = image_name.split('/', 1)[-1].split(":")[0].replace("/", "-")
 
+    if repository + ':' + tag == registry:
+        registry = 'docker.io'
+
     s3 = boto3.client('s3')
 
     file_name = file.split("/")[-1]
@@ -48,6 +50,8 @@ def upload_to_s3(bucket_name, file, account, image_digest, image_name):
         print("Error: AWS credentials not found.")
     except ClientError as e:
         print(f"Error: {e}")
+    except Exception as e:
+        print(e)
 
 def add_date_prefix(filename):
     date_prefix = str(datetime.datetime.now().timestamp()).replace(" ", "_").split(".")[0]
@@ -75,7 +79,6 @@ def failedStep(e):
 def scan():
     context = usecontext.replace(':',"--colon--")
     context = context.replace('/','--slash--')
-    print(namespace)
     sp.run([
             "cinc-auditor","exec",controls,
             "-t","k8s-container://"+context+"/"+namespace+'/'+pod+'/'+container,
